You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@shiro.apache.org by ad...@apache.org on 2009/06/18 05:13:47 UTC

svn commit: r785881 [6/11] - in /incubator/shiro/trunk: ./ all/ core/src/main/java/org/apache/ki/ core/src/main/java/org/apache/shiro/ core/src/main/java/org/apache/shiro/aop/ core/src/main/java/org/apache/shiro/authc/ core/src/main/java/org/apache/shi...

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SessionManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SessionManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SessionValidationScheduler.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SessionValidationScheduler.java Thu Jun 18 03:13:34 2009
@@ -16,15 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt;
+package org.apache.shiro.session.mgt;
 
 /**
  * Interface that should be implemented by classes that can control validating sessions on a regular
- * basis.  This interface is used as a delegate for session validation by the {@link org.apache.ki.session.mgt.DefaultSessionManager}
+ * basis.  This interface is used as a delegate for session validation by the {@link org.apache.shiro.session.mgt.DefaultSessionManager}
  *
  * @author Jeremy Haile
  * @author Les Hazlewood
- * @see org.apache.ki.session.mgt.DefaultSessionManager#setSessionValidationScheduler(SessionValidationScheduler)
+ * @see org.apache.shiro.session.mgt.DefaultSessionManager#setSessionValidationScheduler(SessionValidationScheduler)
  * @since 0.1
  */
 public interface SessionValidationScheduler {

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SimpleSession.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SimpleSession.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SimpleSessionFactory.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SimpleSessionFactory.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt;
+package org.apache.shiro.session.mgt;
 
-import org.apache.ki.session.Session;
+import org.apache.shiro.session.Session;
 
 import java.net.InetAddress;
 import java.util.Map;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/ValidatingSession.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/ValidatingSession.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/ValidatingSession.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/ValidatingSession.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt;
+package org.apache.shiro.session.mgt;
 
-import org.apache.ki.session.InvalidSessionException;
-import org.apache.ki.session.Session;
+import org.apache.shiro.session.InvalidSessionException;
+import org.apache.shiro.session.Session;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/ValidatingSessionManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/ValidatingSessionManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/package-info.java Thu Jun 18 03:13:34 2009
@@ -1,23 +1,23 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-/**
- * EIS (Enterprise Information System)-tier components that can perform CRUD operations for sessions
- * using any EIS API.
- */
-package org.apache.ki.session.mgt.eis;
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+/**
+ * EIS (Enterprise Information System)-tier components that can perform CRUD operations for sessions
+ * using any EIS API.
+ */
+package org.apache.shiro.session.mgt.eis;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/InvalidSubjectException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/InvalidSubjectException.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.subject;
+package org.apache.shiro.subject;
 
 /**
  * Exception thrown when a <tt>Subject</tt> is accessed that has been invalidated.  Usually this occurs

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/MutablePrincipalCollection.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/MutablePrincipalCollection.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/MutablePrincipalCollection.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/MutablePrincipalCollection.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.subject;
+package org.apache.shiro.subject;
 
 import java.util.Collection;
 

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/PrincipalCollection.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/PrincipalCollection.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/PrincipalCollection.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/PrincipalCollection.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.subject;
+package org.apache.shiro.subject;
 
 import java.io.Serializable;
 import java.util.Collection;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/SimplePrincipalCollection.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/SimplePrincipalCollection.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/SimplePrincipalCollection.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/SimplePrincipalCollection.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.subject;
+package org.apache.shiro.subject;
 
 import java.util.ArrayList;
 import java.util.Collection;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/Subject.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/Subject.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/SubjectException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/SubjectException.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.subject;
+package org.apache.shiro.subject;
 
-import org.apache.ki.KiException;
+import org.apache.shiro.ShiroException;
 
 
 /**
@@ -27,7 +27,8 @@
  * @author Jeremy Haile
  * @since 0.1
  */
-public class SubjectException extends KiException {
+public class SubjectException extends ShiroException
+{
 
     /**
      * Creates a new SubjectException.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/ClassUtils.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/ClassUtils.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
 import java.io.InputStream;
 import java.lang.reflect.Constructor;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/CollectionUtils.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/CollectionUtils.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/InstantiationException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/InstantiationException.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
-import org.apache.ki.KiException;
+import org.apache.shiro.ShiroException;
 
 
 /**
@@ -27,7 +27,8 @@
  * @author Les Hazlewood
  * @since 0.2
  */
-public class InstantiationException extends KiException {
+public class InstantiationException extends ShiroException
+{
 
     /**
      * Creates a new InstantiationException.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/JavaEnvironment.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/JavaEnvironment.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/JdbcUtils.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/JdbcUtils.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
 import java.sql.Connection;
 import java.sql.ResultSet;
@@ -30,7 +30,7 @@
  * A set of static helper methods for managing JDBC API objects.
  * <p/>
  * <em>Note:</em> Some parts of this class were copied from the Spring Framework and then modified.
- * They were copied here to prevent Spring dependencies in the Ki core API.  The original license conditions
+ * They were copied here to prevent Spring dependencies in the Shiro core API.  The original license conditions
  * (Apache 2.0) have been maintained.
  *
  * @author Jeremy Haile

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/LifecycleUtils.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/LifecycleUtils.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/LifecycleUtils.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/LifecycleUtils.java Thu Jun 18 03:13:34 2009
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
 import java.util.Collection;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.KiException;
+import org.apache.shiro.ShiroException;
 
 
 /**
@@ -35,22 +35,25 @@
 
     private static final Logger log = LoggerFactory.getLogger(LifecycleUtils.class);
 
-    public static void init(Object o) throws KiException {
+    public static void init(Object o) throws ShiroException
+    {
         if (o instanceof Initializable) {
             init((Initializable) o);
         }
     }
 
-    public static void init(Initializable initializable) throws KiException {
+    public static void init(Initializable initializable) throws ShiroException
+    {
         initializable.init();
     }
 
     /**
      * @param c
-     * @throws org.apache.ki.KiException
+     * @throws org.apache.shiro.ShiroException
      * @since 0.9
      */
-    public static void init(Collection c) throws KiException {
+    public static void init(Collection c) throws ShiroException
+    {
         if (c == null || c.isEmpty()) {
             return;
         }

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/Nameable.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/Nameable.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/Nameable.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/Nameable.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/PatternMatcher.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/PatternMatcher.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/PatternMatcher.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/PatternMatcher.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
 /**
  * Interface for components that can match source strings against a specified pattern string.
@@ -25,7 +25,7 @@
  * regular expressions, or other types of text based patterns.
  *
  * @author Les Hazlewood
- * @see org.apache.ki.util.AntPathMatcher AntPathMatcher
+ * @see org.apache.shiro.util.AntPathMatcher AntPathMatcher
  * @since 0.9 RC2
  */
 public interface PatternMatcher {

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/PermissionUtils.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/PermissionUtils.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/PermissionUtils.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/PermissionUtils.java Thu Jun 18 03:13:34 2009
@@ -16,15 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.LinkedHashSet;
 import java.util.Set;
 
-import org.apache.ki.authz.Permission;
-import org.apache.ki.authz.permission.PermissionResolver;
+import org.apache.shiro.authz.Permission;
+import org.apache.shiro.authz.permission.PermissionResolver;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/RegExPatternMatcher.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/RegExPatternMatcher.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/RegExPatternMatcher.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/RegExPatternMatcher.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
 import java.util.regex.Pattern;
 import java.util.regex.Matcher;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/SoftHashMap.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/SoftHashMap.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/SoftHashMap.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/SoftHashMap.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
 import java.lang.ref.ReferenceQueue;
 import java.lang.ref.SoftReference;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/StringUtils.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/StringUtils.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/StringUtils.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/StringUtils.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
 import java.text.ParseException;
 import java.util.ArrayList;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/ThreadContext.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/ThreadContext.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/ThreadContext.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/ThreadContext.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
 import java.io.Serializable;
 import java.net.InetAddress;
@@ -26,8 +26,8 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.mgt.SecurityManager;
-import org.apache.ki.subject.Subject;
+import org.apache.shiro.mgt.SecurityManager;
+import org.apache.shiro.subject.Subject;
 
 
 /**
@@ -214,7 +214,7 @@
      * @return the Subject object bound to the thread, or <tt>null</tt> if there isn't one bound.
      * @since 0.9
      */
-    public static org.apache.ki.mgt.SecurityManager getSecurityManager() {
+    public static org.apache.shiro.mgt.SecurityManager getSecurityManager() {
         return (SecurityManager) get(SECURITY_MANAGER_KEY);
     }
 

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/UnavailableConstructorException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/UnavailableConstructorException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/UnavailableConstructorException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/UnavailableConstructorException.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
-import org.apache.ki.KiException;
+import org.apache.shiro.ShiroException;
 
 
 /**
@@ -28,7 +28,8 @@
  * @author Les Hazlewood
  * @since 0.2
  */
-public class UnavailableConstructorException extends KiException {
+public class UnavailableConstructorException extends ShiroException
+{
 
     /**
      * Creates a new UnavailableConstructorException.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/UnknownClassException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/UnknownClassException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/package-info.java Thu Jun 18 03:13:34 2009
@@ -1,23 +1,23 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-/**
- * Your run-of-the-mill 'util' pacakge for components and logic widely used across the framework that can't
- * find their home into a proper OO hierarchy (or, most likely for things used across many hierarchies).
- */
-package org.apache.ki.util;
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+/**
+ * Your run-of-the-mill 'util' pacakge for components and logic widely used across the framework that can't
+ * find their home into a proper OO hierarchy (or, most likely for things used across many hierarchies).
+ */
+package org.apache.shiro.util;

Added: incubator/shiro/trunk/core/src/main/resources/org/apache/shiro/realm/text/default-shiro-users.properties
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/resources/org/apache/shiro/realm/text/default-shiro-users.properties?rev=785881&view=auto
==============================================================================
--- incubator/shiro/trunk/core/src/main/resources/org/apache/shiro/realm/text/default-shiro-users.properties (added)
+++ incubator/shiro/trunk/core/src/main/resources/org/apache/shiro/realm/text/default-shiro-users.properties Thu Jun 18 03:13:34 2009
@@ -0,0 +1,62 @@
+#
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+#
+# ============================================================================
+# Failsafe properties-based Realm configuration
+#
+# A Properties-based configuration is static by nature, which means its user,
+# role, and permission definitions contained within do not change during
+# runtime.  This means you can't add or remove any of them during runtime
+# which is probably of little value to a 'real' application.
+#
+# This file primarily exists as a failsafe mechanism in case you don't provide
+# any Realms to the Shiro SecurityManager at startup.  It also serves as a
+# simple and fun example.  But you will want to provide one or more of your
+# own Realms in a real application.
+#
+# The key/value pairs format is defined in the
+# org.apache.shiroiro.realm.text.PropertiesRealm JavaDoc, but it is probably simple
+# enough that you could figure it out from looking at the definitions below.
+#
+# For those that might not understand the references in this file, the
+# definitions are all based on the classic Mel Brooks' film "Spaceballs". ;)
+# ============================================================================
+
+# ------------------------------
+# Users and their assigned roles
+# ------------------------------
+# user 'root' with password 'secret' and the 'root' role
+user.root = secret,root
+# user 'guest' with the password 'guest' and the 'guest' role
+user.guest = guest,guest
+# user 'presidentskroob' with password '12345' ("That's the same combination on my luggage!!!" ;)), and role 'president'
+user.presidentskroob = 12345,president
+# user 'darkhelmet' with password 'ludicrousspeed' and roles 'darklord' and 'schwartz'
+user.darkhelmet = ludicrousspeed,darklord,schwartz
+# user 'lonestarr' with password 'vespa' and roles 'goodguy' and 'schwartz'
+user.lonestarr = vespa,goodguy,schwartz
+
+# -------------------------------
+# Roles with assigned permissions
+# -------------------------------
+# 'root' role has all permissions, indicated by the wildcard '*'
+role.root = *
+# The 'schwartz' role can do anything (*) with any lightsaber:
+role.schwartz = lightsaber:*
+# The 'goodguy' role is allowed to 'drive' (action) the winnebago (type) with license plate 'eagle5' (instance specific id)
+role.goodguy = winnebago:drive:eagle5

Propchange: incubator/shiro/trunk/core/src/main/resources/org/apache/shiro/realm/text/default-shiro-users.properties
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/shiro/trunk/core/src/main/resources/org/apache/shiro/realm/text/default-shiro-users.properties
------------------------------------------------------------------------------
    svn:keywords = Date Revision

Propchange: incubator/shiro/trunk/core/src/main/resources/org/apache/shiro/realm/text/default-shiro-users.properties
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/AtUnitTestBase.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/AtUnitTestBase.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/AtUnitTestBase.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/AtUnitTestBase.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki;
+package org.apache.shiro;
 
 /*import atunit.AtUnit;
 import atunit.Container;

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/ExceptionTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/ExceptionTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/ExceptionTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/ExceptionTest.java Thu Jun 18 03:13:34 2009
@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki;
+package org.apache.shiro;
 
 import junit.framework.TestCase;
 import org.junit.Test;
 
-import org.apache.ki.util.ClassUtils;
+import org.apache.shiro.util.ClassUtils;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/ConcurrentAccessExceptionTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/ConcurrentAccessExceptionTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/ConcurrentAccessExceptionTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/ConcurrentAccessExceptionTest.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc;
+package org.apache.shiro.authc;
 
-import org.apache.ki.ExceptionTest;
+import org.apache.shiro.ExceptionTest;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/ExcessiveAttemptsExceptionTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/ExcessiveAttemptsExceptionTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/ExcessiveAttemptsExceptionTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/ExcessiveAttemptsExceptionTest.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc;
+package org.apache.shiro.authc;
 
-import org.apache.ki.ExceptionTest;
+import org.apache.shiro.ExceptionTest;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/ExpiredCredentialsExceptionTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/ExpiredCredentialsExceptionTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/ExpiredCredentialsExceptionTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/ExpiredCredentialsExceptionTest.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc;
+package org.apache.shiro.authc;
 
-import org.apache.ki.ExceptionTest;
+import org.apache.shiro.ExceptionTest;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/IncorrectCredentialsExceptionTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/IncorrectCredentialsExceptionTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/IncorrectCredentialsExceptionTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/IncorrectCredentialsExceptionTest.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc;
+package org.apache.shiro.authc;
 
-import org.apache.ki.ExceptionTest;
+import org.apache.shiro.ExceptionTest;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/LockedAccountExceptionTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/LockedAccountExceptionTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/LockedAccountExceptionTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/LockedAccountExceptionTest.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc;
+package org.apache.shiro.authc;
 
-import org.apache.ki.ExceptionTest;
+import org.apache.shiro.ExceptionTest;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/SimpleAuthenticationInfoTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/SimpleAuthenticationInfoTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/SimpleAuthenticationInfoTest.java (original)
+++ incubator/shiro/trunk/core/src/test/java/org/apache/shiro/authc/SimpleAuthenticationInfoTest.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc;
+package org.apache.shiro.authc;
 
 import org.junit.Test;
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SessionManager.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SessionManager.java Thu Jun 18 03:13:34 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt;
+package org.apache.shiro.session.mgt;
 
-import org.apache.ki.authz.AuthorizationException;
-import org.apache.ki.authz.HostUnauthorizedException;
-import org.apache.ki.session.InvalidSessionException;
+import org.apache.shiro.authz.AuthorizationException;
+import org.apache.shiro.authz.HostUnauthorizedException;
+import org.apache.shiro.session.InvalidSessionException;
 
 import java.io.Serializable;
 import java.net.InetAddress;
@@ -30,7 +30,7 @@
 
 /**
  * A SessionManager manages the creation, maintenance, and clean-up of all application
- * {@link org.apache.ki.session.Session Session}s.
+ * {@link org.apache.shiro.session.Session Session}s.
  *
  * @author Les Hazlewood
  * @since 0.1
@@ -83,10 +83,10 @@
      * <p/>
      * This method is mainly used in framework development, as the implementation will often relay the argument
      * to an underlying {@link SessionFactory} which could use the {@code Map} to construct the internal Session
      * instance in a specific manner.  This allows pluggable {@link org.apache.ki.session.Session Session} creation
      * logic by simply injecting a {@code SessionFactory} into the {@code SecurityManager or SessionManager} instance.
      * <p/>
      * For example, Ki's default implementation of the
      * {@link #start(InetAddress) start(InetAddress)} method merely adds the InetAddress to a Map instance and passes
      * that Map into this method for delegation to an underlying {@link SessionFactory}.
      *
@@ -108,7 +108,7 @@
      *
      * @param sessionId the system identifier for the session of interest.
      * @return the system time the specified session was started (i.e. created).
-     * @see org.apache.ki.session.Session#getStartTimestamp()
+     * @see org.apache.shiro.session.Session#getStartTimestamp()
      */
     Date getStartTimestamp(Serializable sessionId);
 
@@ -118,8 +118,8 @@
      *
      * @param sessionId the system identifier for the session of interest
      * @return time the session last accessed the system
-     * @see org.apache.ki.session.Session#getLastAccessTime()
-     * @see org.apache.ki.session.Session#touch()
+     * @see org.apache.shiro.session.Session#getLastAccessTime()
+     * @see org.apache.shiro.session.Session#touch()
      */
     Date getLastAccessTime(Serializable sessionId);
 
@@ -153,7 +153,7 @@
      *
      * @param sessionId the system identifier of the session of interest.
      * @return the time in milliseconds that the specified session may remain idle before expiring.
-     * @throws org.apache.ki.session.InvalidSessionException
+     * @throws org.apache.shiro.session.InvalidSessionException
      *          if the session has been stopped or expired prior to calling this method.
      * @since 0.2
      */
@@ -169,7 +169,7 @@
      *
      * @param sessionId           the system identifier of the session of interest.
      * @param maxIdleTimeInMillis the time in milliseconds that the specified session may remain idle before expiring.
-     * @throws org.apache.ki.session.InvalidSessionException
+     * @throws org.apache.shiro.session.InvalidSessionException
      *          if the session has been stopped or expired prior to calling this method.
      * @since 0.2
      */
@@ -180,9 +180,9 @@
      * can be used to explicitly ensure that a session does not time out.
      *
      * @param sessionId the id of the session to update.
-     * @throws org.apache.ki.session.InvalidSessionException
+     * @throws org.apache.shiro.session.InvalidSessionException
      *          if the session has been stopped or expired prior to calling this method.
-     * @see org.apache.ki.session.Session#touch
+     * @see org.apache.shiro.session.Session#touch
      */
     void touch(Serializable sessionId) throws InvalidSessionException;
 
@@ -204,7 +204,7 @@
      * @param sessionId the system identfier of the system to destroy.
      * @throws InvalidSessionException if the session has stopped or expired prior to calling
      *                                 this method.
-     * @see org.apache.ki.session.Session#stop
+     * @see org.apache.shiro.session.Session#stop
      */
     void stop(Serializable sessionId) throws InvalidSessionException;
 
@@ -216,7 +216,7 @@
      * @return the keys of all attributes stored under the specified session, or an empty collection if
      *         there are no session attributes.
      * @throws InvalidSessionException if the specified session has stopped or expired prior to calling this method.
-     * @see org.apache.ki.session.Session#getAttributeKeys()
+     * @see org.apache.shiro.session.Session#getAttributeKeys()
      * @since 0.2
      */
     Collection<Object> getAttributeKeys(Serializable sessionId);
@@ -230,7 +230,7 @@
      * @return the object bound under the specified {@code key} name or {@code null} if there is
      *         no object bound under that name.
      * @throws InvalidSessionException if the specified session has stopped or expired prior to calling this method.
-     * @see org.apache.ki.session.Session#getAttribute(Object key)
+     * @see org.apache.shiro.session.Session#getAttribute(Object key)
      */
     Object getAttribute(Serializable sessionId, Object key) throws InvalidSessionException;
 
@@ -246,7 +246,7 @@
      * @param key       the name under which the {@code value} object will be bound in this session
      * @param value     the object to bind in this session.
      * @throws InvalidSessionException if the specified session has stopped or expired prior to calling this method.
      * @see org.apache.ki.session.Session#setAttribute(Object key, Object value)
      */
     void setAttribute(Serializable sessionId, Object key, Object value) throws InvalidSessionException;
 
@@ -258,7 +258,7 @@
      * @return the object removed or {@code null} if there was no object bound under the specified
      *         {@code key} name.
      * @throws InvalidSessionException if the specified session has stopped or expired prior to calling this method.
-     * @see org.apache.ki.session.Session#removeAttribute(Object key)
+     * @see org.apache.shiro.session.Session#removeAttribute(Object key)
      */
     Object removeAttribute(Serializable sessionId, Object key) throws InvalidSessionException;
 }
@@ -83,10 +83,10 @@
      * This method is mainly used in framework development, as the implementation will often relay the argument
      * to an underlying {@link SessionFactory} which could use the {@code Map} to construct the internal Session
-     * instance in a specific manner.  This allows pluggable {@link org.apache.ki.session.Session Session} creation
+     * instance in a specific manner.  This allows pluggable {@link org.apache.shiro.session.Session Session} creation
      * logic by simply injecting a {@code SessionFactory} into the {@code SecurityManager or SessionManager} instance.
      * <p/>
@@ -83,10 +83,10 @@
      * logic by simply injecting a {@code SessionFactory} into the {@code SecurityManager or SessionManager} instance.
      * <p/>
-     * For example, Ki's default implementation of the
+     * For example, Shiro's default implementation of the
      * {@link #start(InetAddress) start(InetAddress)} method merely adds the InetAddress to a Map instance and passes
      * that Map into this method for delegation to an underlying {@link SessionFactory}.
@@ -246,7 +246,7 @@
      * @param value     the object to bind in this session.
      * @throws InvalidSessionException if the specified session has stopped or expired prior to calling this method.
-     * @see org.apache.ki.session.Session#setAttribute(Object key, Object value)
+     * @see org.apache.shiro.session.Session#setAttribute(Object key, Object value)
      */
     void setAttribute(Serializable sessionId, Object key, Object value) throws InvalidSessionException;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SessionValidationScheduler.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SessionValidationScheduler.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SimpleSession.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SimpleSession.java Thu Jun 18 03:13:34 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt;
+package org.apache.shiro.session.mgt;
 
-import org.apache.ki.session.ExpiredSessionException;
-import org.apache.ki.session.InvalidSessionException;
-import org.apache.ki.session.StoppedSessionException;
+import org.apache.shiro.session.ExpiredSessionException;
+import org.apache.shiro.session.InvalidSessionException;
+import org.apache.shiro.session.StoppedSessionException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -31,7 +31,7 @@
 
 
 /**
  * Simple {@link org.apache.ki.session.Session} JavaBeans-compatible POJO implementation, intended to be used on the
  * business/server tier.
  *
  * @author Les Hazlewood
@@ -31,7 +31,7 @@
 
 /**
- * Simple {@link org.apache.ki.session.Session} JavaBeans-compatible POJO implementation, intended to be used on the
+ * Simple {@link org.apache.shiro.session.Session} JavaBeans-compatible POJO implementation, intended to be used on the
  * business/server tier.
  *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SimpleSessionFactory.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/SimpleSessionFactory.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/ValidatingSessionManager.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/ValidatingSessionManager.java Thu Jun 18 03:13:34 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt;
+package org.apache.shiro.session.mgt;
 
 import java.io.Serializable;
 
-import org.apache.ki.session.InvalidSessionException;
+import org.apache.shiro.session.InvalidSessionException;
 
 
 /**
@@ -67,8 +67,8 @@
      * proactive systems, this {@code validateSessions} method should be invoked regularaly
      * anyway to <em>guarantee</em> no orphans exist.
      * <p/>
      * <p><b>Note:</b> Ki supports automatic execution of this method at a regular interval
      * by using {@link SessionValidationScheduler}s.  The Ki default SecurityManager implementations
      * needing session validation will create and use one by default if one is not provided by the
      * application configuration.
      */
@@ -78,7 +78,7 @@
      * Proactively validates a single session.
      *
      * @param sessionId the id of the session to validate
-     * @throws org.apache.ki.session.InvalidSessionException
+     * @throws org.apache.shiro.session.InvalidSessionException
      *          if, upon validation, the session was stopped or expired.
      */
     void validateSession(Serializable sessionId) throws InvalidSessionException;
@@ -67,8 +67,8 @@
      * anyway to <em>guarantee</em> no orphans exist.
      * <p/>
-     * <p><b>Note:</b> Ki supports automatic execution of this method at a regular interval
-     * by using {@link SessionValidationScheduler}s.  The Ki default SecurityManager implementations
+     * <p><b>Note:</b> Shiro supports automatic execution of this method at a regular interval
+     * by using {@link SessionValidationScheduler}s.  The Shiro default SecurityManager implementations
      * needing session validation will create and use one by default if one is not provided by the
      * application configuration.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/CachingSessionDAO.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/CachingSessionDAO.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/CachingSessionDAO.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/CachingSessionDAO.java Thu Jun 18 03:13:34 2009
@@ -16,18 +16,18 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt.eis;
+package org.apache.shiro.session.mgt.eis;
 
 import java.io.Serializable;
 import java.util.Collection;
 import java.util.Collections;
 
-import org.apache.ki.cache.Cache;
-import org.apache.ki.cache.CacheManager;
-import org.apache.ki.cache.CacheManagerAware;
-import org.apache.ki.session.Session;
-import org.apache.ki.session.UnknownSessionException;
-import org.apache.ki.session.mgt.ValidatingSession;
+import org.apache.shiro.cache.Cache;
+import org.apache.shiro.cache.CacheManager;
+import org.apache.shiro.cache.CacheManagerAware;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.session.UnknownSessionException;
+import org.apache.shiro.session.mgt.ValidatingSession;
 
 
 /**
@@ -35,7 +35,7 @@
  * use it and the underlying EIS (Enterprise Information System) for enhanced performance.
  *
  * <p>This implementation caches all active sessions in a cache created by a
  * {@link org.apache.ki.cache.CacheManager}.  All <tt>SessionDAO</tt> methods are implemented by this class to employ
  * caching behavior and delegates the actual EIS operations to respective do* methods to be implemented by
  * subclasses (doCreate, doRead, etc).
  *
@@ -45,9 +45,9 @@
 public abstract class CachingSessionDAO implements SessionDAO, CacheManagerAware {
 
     /**
      * The default active sessions cache name, equal to <code>ki-activeSessionCache</code>.
      */
-    public static final String ACTIVE_SESSION_CACHE_NAME = "ki-activeSessionCache";
+    public static final String ACTIVE_SESSION_CACHE_NAME = "shiro-activeSessionCache";
 
     /**
      * The CacheManager to use to acquire the Session cache.
@@ -204,8 +204,8 @@
 
     /**
      * Caches the specified session under the key <code>sessionId</code>.  If the Session is an instance of
      * {@link org.apache.ki.session.mgt.ValidatingSession ValidatingSession}, it will only be cached if the
      * session is {@link org.apache.ki.session.mgt.ValidatingSession#isValid() valid}.
      *
      * @param session the session to cache
      * @param sessionId the id of the session, to be used as the cache key.
@@ -273,7 +273,7 @@
      *
      * @param session the Session instance to persist to the EIS.
      * @return the id of the session created in the EIS (i.e. this is almost always a primary key and should be the
      *         value returned from {@link org.apache.ki.session.Session#getId() Session.getId()}.
      */
     protected abstract Serializable doCreate(Session session);
 
@@ -35,7 +35,7 @@
  *
  * <p>This implementation caches all active sessions in a cache created by a
- * {@link org.apache.ki.cache.CacheManager}.  All <tt>SessionDAO</tt> methods are implemented by this class to employ
+ * {@link org.apache.shiro.cache.CacheManager}.  All <tt>SessionDAO</tt> methods are implemented by this class to employ
  * caching behavior and delegates the actual EIS operations to respective do* methods to be implemented by
  * subclasses (doCreate, doRead, etc).
@@ -45,9 +45,9 @@
 
     /**
-     * The default active sessions cache name, equal to <code>ki-activeSessionCache</code>.
+     * The default active sessions cache name, equal to <code>shiro-activeSessionCache</code>.
      */
@@ -204,8 +204,8 @@
     /**
      * Caches the specified session under the key <code>sessionId</code>.  If the Session is an instance of
-     * {@link org.apache.ki.session.mgt.ValidatingSession ValidatingSession}, it will only be cached if the
-     * session is {@link org.apache.ki.session.mgt.ValidatingSession#isValid() valid}.
+     * {@link org.apache.shiro.session.mgt.ValidatingSession ValidatingSession}, it will only be cached if the
+     * session is {@link org.apache.shiro.session.mgt.ValidatingSession#isValid() valid}.
      *
      * @param session the session to cache
@@ -273,7 +273,7 @@
      * @param session the Session instance to persist to the EIS.
      * @return the id of the session created in the EIS (i.e. this is almost always a primary key and should be the
-     *         value returned from {@link org.apache.ki.session.Session#getId() Session.getId()}.
+     *         value returned from {@link org.apache.shiro.session.Session#getId() Session.getId()}.
      */
     protected abstract Serializable doCreate(Session session);

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/MemorySessionDAO.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/MemorySessionDAO.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/MemorySessionDAO.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/MemorySessionDAO.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt.eis;
+package org.apache.shiro.session.mgt.eis;
 
 import java.io.Serializable;
 import java.util.Random;
@@ -24,10 +24,10 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.cache.HashtableCacheManager;
-import org.apache.ki.session.Session;
-import org.apache.ki.session.mgt.SimpleSession;
-import org.apache.ki.util.JavaEnvironment;
+import org.apache.shiro.cache.HashtableCacheManager;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.session.mgt.SimpleSession;
+import org.apache.shiro.util.JavaEnvironment;
 
 
 /**
@@ -35,7 +35,7 @@
  * {@link #setCacheManager CacheManager} for Session caching and in-memory persistence.
  *
  * <p><b>PLEASE NOTE</b> the default CacheManager internal to this implementation is a
  * {@link org.apache.ki.cache.HashtableCacheManager HashtableCacheManager}, which IS NOT RECOMMENDED for production environments.
  *
  * <p>If you
  * want to use the MemorySessionDAO in production environments, such as those that require session data to be
@@ -43,12 +43,12 @@
  *
  * <ul>
  * <li>Configure it with a production-quality CacheManager. The
  * {@link org.apache.ki.cache.ehcache.EhCacheManager EhCacheManager} is one such implementation.  It is not used by default
  * to prevent a forced runtime dependency on ehcache.jar that may not be required in many environments)</li><br/>
  * <li>If you need session information beyond their transient start/stop lifetimes, you should subclass this one and
  * override the <tt>do*</tt> methods to perform CRUD operations using an EIS-tier API (e.g. Hibernate/JPA/JCR/etc).
  * This class implementation does not retain sessions after they have been stopped or expired, so you would need to
  * override these methods to ensure Sessions can be accessed beyond Ki's needs.</li>
  * </ul>
  *
  * @author Les Hazlewood
@@ -35,7 +35,7 @@
  *
  * <p><b>PLEASE NOTE</b> the default CacheManager internal to this implementation is a
- * {@link org.apache.ki.cache.HashtableCacheManager HashtableCacheManager}, which IS NOT RECOMMENDED for production environments.
+ * {@link org.apache.shiro.cache.HashtableCacheManager HashtableCacheManager}, which IS NOT RECOMMENDED for production environments.
  *
  * <p>If you
@@ -43,12 +43,12 @@
  * <ul>
  * <li>Configure it with a production-quality CacheManager. The
- * {@link org.apache.ki.cache.ehcache.EhCacheManager EhCacheManager} is one such implementation.  It is not used by default
+ * {@link org.apache.shiro.cache.ehcache.EhCacheManager EhCacheManager} is one such implementation.  It is not used by default
  * to prevent a forced runtime dependency on ehcache.jar that may not be required in many environments)</li><br/>
  * <li>If you need session information beyond their transient start/stop lifetimes, you should subclass this one and
@@ -43,12 +43,12 @@
  * override the <tt>do*</tt> methods to perform CRUD operations using an EIS-tier API (e.g. Hibernate/JPA/JCR/etc).
  * This class implementation does not retain sessions after they have been stopped or expired, so you would need to
- * override these methods to ensure Sessions can be accessed beyond Ki's needs.</li>
+ * override these methods to ensure Sessions can be accessed beyond Shiro's needs.</li>
  * </ul>
  *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/SessionDAO.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/SessionDAO.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/SessionDAO.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/SessionDAO.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt.eis;
+package org.apache.shiro.session.mgt.eis;
 
-import org.apache.ki.session.Session;
-import org.apache.ki.session.UnknownSessionException;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.session.UnknownSessionException;
 
 import java.io.Serializable;
 import java.util.Collection;
@@ -28,11 +28,11 @@
 /**
  * Data Access Object design pattern specification to enable {@link Session} access to an
  * EIS (Enterprise Information System).  It provides your four typical CRUD methods:
- * {@link #create}, {@link #readSession(java.io.Serializable)}, {@link #update(org.apache.ki.session.Session)},
- * and {@link #delete(org.apache.ki.session.Session)}.
+ * {@link #create}, {@link #readSession(java.io.Serializable)}, {@link #update(org.apache.shiro.session.Session)},
+ * and {@link #delete(org.apache.shiro.session.Session)}.
  * <p/>
  * The remaining {@link #getActiveSessions()} method exists as a support mechanism to pre-emptively orphaned sessions,
  * typically by {@link org.apache.ki.session.mgt.ValidatingSessionManager ValidatingSessionManager}s), and should
  * be as performant as possible, especially if there are thousands of active sessions.  Large scale/high performance
  * implementations will often return a subset of the total active sessions and perform validation a little more
  * frequently, rather than return a massive set and infrequently validate.
@@ -46,7 +46,7 @@
      * Inserts a new Session record into the underling EIS (e.g. Relational database, file system, persistent cache,
      * etc, depending on the DAO implementation).
      * <p/>
-     * After this method is invoked, the {@link org.apache.ki.session.Session#getId()}
+     * After this method is invoked, the {@link org.apache.shiro.session.Session#getId()}
      * method executed on the argument must return a valid session identifier.  That is, the following should
      * always be true:
      * <p/>
@@ -56,7 +56,7 @@
      * Implementations are free to throw any exceptions that might occur due to
      * integrity violation constraints or other EIS related errors.
      *
      * @param session the {@link org.apache.ki.session.Session} object to create in the EIS.
      * @return the EIS id (e.g. primary key) of the created <tt>Session</tt> object.
      */
     Serializable create(Session session);
@@ -83,7 +83,7 @@
      * errors.
      *
      * @param session the Session to update
-     * @throws org.apache.ki.session.UnknownSessionException
+     * @throws org.apache.shiro.session.UnknownSessionException
      *          if no existing EIS session record exists with the
      *          identifier of {@link Session#getId() session.getSessionId()}
      */
@@ -109,7 +109,7 @@
      * implementations will often return a subset of the total active sessions and perform validation a little more
      * frequently, rather than return a massive set and validate infrequently.  If performant and possible, it would
      * make sense to return the oldest unstopped sessions available, ordered by
-     * {@link org.apache.ki.session.Session#getLastAccessTime() lastAccessTime}.
+     * {@link org.apache.shiro.session.Session#getLastAccessTime() lastAccessTime}.
      * <h4>Smart Results</h4>
      * <em>Ideally</em> this method would only return active sessions that the EIS was certain should be invalided.
      * Typically that is any session that is not stopped and where its lastAccessTimestamp is older than the session
@@ -117,7 +117,7 @@
      * <p/>
      * For example, if sessions were backed by a relational database or SQL-92 'queryable' enterprise cache, you might
      * return something similar to the results returned by this query (assuming
      * {@link org.apache.ki.session.mgt.SimpleSession SimpleSession}s were being stored):
      * <pre>
      * select * from sessions s where s.lastAccessTimestamp < ? and s.stopTimestamp is null
      * </pre>
@@ -28,11 +28,11 @@
  * <p/>
  * The remaining {@link #getActiveSessions()} method exists as a support mechanism to pre-emptively orphaned sessions,
- * typically by {@link org.apache.ki.session.mgt.ValidatingSessionManager ValidatingSessionManager}s), and should
+ * typically by {@link org.apache.shiro.session.mgt.ValidatingSessionManager ValidatingSessionManager}s), and should
  * be as performant as possible, especially if there are thousands of active sessions.  Large scale/high performance
  * implementations will often return a subset of the total active sessions and perform validation a little more
@@ -56,7 +56,7 @@
      * integrity violation constraints or other EIS related errors.
      *
-     * @param session the {@link org.apache.ki.session.Session} object to create in the EIS.
+     * @param session the {@link org.apache.shiro.session.Session} object to create in the EIS.
      * @return the EIS id (e.g. primary key) of the created <tt>Session</tt> object.
      */
@@ -117,7 +117,7 @@
      * For example, if sessions were backed by a relational database or SQL-92 'queryable' enterprise cache, you might
      * return something similar to the results returned by this query (assuming
-     * {@link org.apache.ki.session.mgt.SimpleSession SimpleSession}s were being stored):
+     * {@link org.apache.shiro.session.mgt.SimpleSession SimpleSession}s were being stored):
      * <pre>
      * select * from sessions s where s.lastAccessTimestamp < ? and s.stopTimestamp is null

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/SessionDAOAware.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/SessionDAOAware.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/SessionDAOAware.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/SessionDAOAware.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt.eis;
+package org.apache.shiro.session.mgt.eis;
 
 /**
  * Allows interested components to receive a configured {@link SessionDAO} instance.
@@ -27,9 +27,9 @@
 public interface SessionDAOAware {
 
     /**
      * Sets the {@link SessionDAO} to use for {@link org.apache.ki.session.Session Session} CRUD operations.
      *
      * @param sessionDAO the {@link SessionDAO} to use for {@link org.apache.ki.session.Session Session} CRUD operations.
      */
     void setSessionDAO(SessionDAO sessionDAO);
 }
@@ -27,9 +27,9 @@
 
     /**
-     * Sets the {@link SessionDAO} to use for {@link org.apache.ki.session.Session Session} CRUD operations.
+     * Sets the {@link SessionDAO} to use for {@link org.apache.shiro.session.Session Session} CRUD operations.
      *
@@ -27,9 +27,9 @@
      *
-     * @param sessionDAO the {@link SessionDAO} to use for {@link org.apache.ki.session.Session Session} CRUD operations.
+     * @param sessionDAO the {@link SessionDAO} to use for {@link org.apache.shiro.session.Session Session} CRUD operations.
      */
     void setSessionDAO(SessionDAO sessionDAO);

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/eis/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/mgt/package-info.java Thu Jun 18 03:13:34 2009
@@ -1,22 +1,22 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-/**
- * {@link org.apache.ki.session.mgt.SessionManager SessionManager} components supporting enterprise session management.
- */
-package org.apache.ki.session.mgt;
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+/**
+ * {@link org.apache.shiro.session.mgt.SessionManager SessionManager} components supporting enterprise session management.
+ */
+package org.apache.shiro.session.mgt;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/session/package-info.java Thu Jun 18 03:13:34 2009
@@ -20,17 +20,17 @@
  * Components related to managing sessions, the time-based data contexts in which a Subject
  * interacts with an application.
  * <p/>
  * Sessions in Ki are completely POJO-based and do not <em>require</em> an application to use Web-based
  * or EJB-based session management infrastructure - the client and/or server technoloy is irrelevent in
  * Ki's architecture, allowing session management to be employed in the smallest standalone application
  * to the largest enterprise deployments.
  * <p/>
  * This design decision opens up a new world to Java applications - most notably the ability to participate in
  * a session regardless if the client is using HTTP, custom sockets, web services, or even non-Java progamming
  * languages. Aside from Ki, there is currently no technology in Java today allows this heterogenous
  * client-session capability.
  * <p/>
  * Also because of this freedom, Ki naturally supports Single Sign-On for any application as well, using
  * this heterogeneous session support.
  */
-package org.apache.ki.session;
+package org.apache.shiro.session;
@@ -20,17 +20,17 @@
  * interacts with an application.
  * <p/>
- * Sessions in Ki are completely POJO-based and do not <em>require</em> an application to use Web-based
+ * Sessions in Shiro are completely POJO-based and do not <em>require</em> an application to use Web-based
  * or EJB-based session management infrastructure - the client and/or server technoloy is irrelevent in
@@ -20,17 +20,17 @@
  * or EJB-based session management infrastructure - the client and/or server technoloy is irrelevent in
- * Ki's architecture, allowing session management to be employed in the smallest standalone application
+ * Shiro's architecture, allowing session management to be employed in the smallest standalone application
  * to the largest enterprise deployments.
  * <p/>
@@ -20,17 +20,17 @@
  * This design decision opens up a new world to Java applications - most notably the ability to participate in
  * a session regardless if the client is using HTTP, custom sockets, web services, or even non-Java progamming
- * languages. Aside from Ki, there is currently no technology in Java today allows this heterogenous
+ * languages. Aside from Shiro, there is currently no technology in Java today allows this heterogenous
  * client-session capability.
  * <p/>
@@ -20,17 +20,17 @@
  * client-session capability.
  * <p/>
- * Also because of this freedom, Ki naturally supports Single Sign-On for any application as well, using
+ * Also because of this freedom, Shiro naturally supports Single Sign-On for any application as well, using
  * this heterogeneous session support.
  */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/DelegatingSubject.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/DelegatingSubject.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/DelegatingSubject.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/DelegatingSubject.java Thu Jun 18 03:13:34 2009
@@ -16,20 +16,20 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.subject;
+package org.apache.shiro.subject;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.InetAuthenticationToken;
-import org.apache.ki.authz.AuthorizationException;
-import org.apache.ki.authz.Permission;
-import org.apache.ki.authz.UnauthenticatedException;
-import org.apache.ki.mgt.SecurityManager;
-import org.apache.ki.session.InvalidSessionException;
-import org.apache.ki.session.ProxiedSession;
-import org.apache.ki.session.Session;
-import org.apache.ki.session.mgt.DelegatingSession;
-import org.apache.ki.util.ThreadContext;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.InetAuthenticationToken;
+import org.apache.shiro.authz.AuthorizationException;
+import org.apache.shiro.authz.Permission;
+import org.apache.shiro.authz.UnauthenticatedException;
+import org.apache.shiro.mgt.SecurityManager;
+import org.apache.shiro.session.InvalidSessionException;
+import org.apache.shiro.session.ProxiedSession;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.session.mgt.DelegatingSession;
+import org.apache.shiro.util.ThreadContext;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -41,7 +41,7 @@
 
 /**
  * Implementation of the <tt>Subject</tt> interface that delegates
  * method calls to an underlying {@link org.apache.ki.mgt.SecurityManager SecurityManager} instance for security checks.
  * It is essentially a <tt>SecurityManager</tt> proxy.
  * <p/>
  * This implementation does not maintain state such as roles and permissions (only <code>Subject</code>
@@ -41,7 +41,7 @@
 /**
  * Implementation of the <tt>Subject</tt> interface that delegates
- * method calls to an underlying {@link org.apache.ki.mgt.SecurityManager SecurityManager} instance for security checks.
+ * method calls to an underlying {@link org.apache.shiro.mgt.SecurityManager SecurityManager} instance for security checks.
  * It is essentially a <tt>SecurityManager</tt> proxy.
  * <p/>

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/InvalidSubjectException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/InvalidSubjectException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/Subject.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/Subject.java Thu Jun 18 03:13:34 2009
@@ -16,28 +16,28 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.subject;
+package org.apache.shiro.subject;
 
 import java.util.Collection;
 import java.util.List;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authz.AuthorizationException;
-import org.apache.ki.authz.Permission;
-import org.apache.ki.session.Session;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authz.AuthorizationException;
+import org.apache.shiro.authz.Permission;
+import org.apache.shiro.session.Session;
 
 /**
  * A <tt>Subject</tt> represents state and security operations for a <em>single</em> application user.
  * These operations include authentication (login/logout), authorization (access control), and
  * session access. It is Ki's primary mechanism for single-user security functionality.
  *
  * <p>Note that there are many *Permission methods in this interface overloaded to accept String arguments instead of
  * {@link Permission Permission} instances. They are a convenience allowing the caller to use a String representation of
  * a {@link Permission Permission} if desired.  The underlying Authorization subsystem implementations will usually
  * simply convert these String values to {@link Permission Permission} instances and then just call the corresponding
  * type-safe method.  (Ki's default implementations do String-to-Permission conversion for these methods using
  * {@link org.apache.ki.authz.permission.PermissionResolver PermissionResolver}s.)
  *
  * <p>These overloaded *Permission methods <em>do</em> forego type-saftey for the benefit of convenience and simplicity,
  * so you should choose which ones to use based on your preferences and needs.
@@ -55,15 +55,15 @@
      * <p>The term <em>principal</em> is just a fancy security term for any identifying attribute(s) of an application
      * user, such as a username, or user id, or public key, or anything else you might use in your application to
      * identify a user.  And although given names and family names (first/last) are technically principals as well,
      * Ki expects the object(s) returned from this method to be uniquely identifying attibute(s) for
      * your application.  This implies that things like given names and family names are usually poor candidates as
      * return values since they are rarely guaranteed to be unique.</p>
      *
      * <p>Most single-Realm applications would return from this method a single unique principal as noted above
      * (for example a String username or Long user id, etc, etc).  Single-realm applications represent the large
      * majority of Ki applications.</p>
      *
      * <p>However, in <em>multi</em>-Realm configurations, which are fully supported by Ki as well, it is
      * possible that the return value encapsulates more than one principal.  Typically multi-realm applications need to
      * retain the unique principals for <em>each</em> Realm so subsequent security checks against these Realms can
      * utilize these multiple principals.  In these cases, the object returned could be a Collection or any
@@ -162,7 +162,7 @@
     /**
      * Returns <tt>true</tt> if this Subject implies all of the specified permission strings, <tt>false</tt> otherwise.
      *
      * <p>This is an overloaded method for the corresponding type-safe {@link org.apache.ki.authz.Permission Permission} variant.
      * Please see the class-level JavaDoc for more information on these String-based permission methods.
      *
      * @param permissions the String representations of the Permissions that are being checked.
@@ -187,13 +187,13 @@
      * Ensures this Subject implies the specified permission String.
      *
      * <p>If this subject's existing associated permissions do not {@link Permission#implies(Permission)} imply}
      * the given permission, an {@link org.apache.ki.authz.AuthorizationException} will be thrown.
      *
      * <p>This is an overloaded method for the corresponding type-safe {@link Permission Permission} variant.
      * Please see the class-level JavaDoc for more information on these String-based permission methods.
      *
      * @param permission the String representation of the Permission to check.
-     * @throws org.apache.ki.authz.AuthorizationException
+     * @throws org.apache.shiro.authz.AuthorizationException
      *          if the user does not have the permission.
      * @since 0.9
      */
@@ -203,22 +203,22 @@
      * Ensures this Subject {@link Permission#implies(Permission) implies} the specified <tt>Permission</tt>.
      *
      * <p>If this subject's exisiting associated permissions do not {@link Permission#implies(Permission) imply}
      * the given permission, an {@link org.apache.ki.authz.AuthorizationException} will be thrown.
      *
      * @param permission the Permission to check.
-     * @throws org.apache.ki.authz.AuthorizationException
+     * @throws org.apache.shiro.authz.AuthorizationException
      *          if this Subject does not have the permission.
      */
     void checkPermission(Permission permission) throws AuthorizationException;
 
     /**
      * Ensures this Subject
      * {@link org.apache.ki.authz.Permission#implies(org.apache.ki.authz.Permission) implies} all of the
      * specified permission strings.
      *
      * If this subject's exisiting associated permissions do not
      * {@link org.apache.ki.authz.Permission#implies(org.apache.ki.authz.Permission) imply} all of the given permissions,
      * an {@link org.apache.ki.authz.AuthorizationException} will be thrown.
      *
      * <p>This is an overloaded method for the corresponding type-safe {@link Permission Permission} variant.
      * Please see the class-level JavaDoc for more information on these String-based permission methods.
@@ -231,12 +231,12 @@
 
     /**
      * Ensures this Subject
      * {@link org.apache.ki.authz.Permission#implies(org.apache.ki.authz.Permission) implies} all of the
      * specified permission strings.
      *
      * If this subject's exisiting associated permissions do not
      * {@link org.apache.ki.authz.Permission#implies(org.apache.ki.authz.Permission) imply} all of the given permissions,
      * an {@link org.apache.ki.authz.AuthorizationException} will be thrown.
      *
      * @param permissions the Permissions to check.
      * @throws AuthorizationException if this Subject does not have all of the given permissions.
@@ -275,20 +275,20 @@
 
     /**
      * Asserts this Subject has the specified role by returning quietly if they do or throwing an
      * {@link org.apache.ki.authz.AuthorizationException} if they do not.
      *
      * @param roleIdentifier the application-specific role identifier (usually a role id or role name ).
-     * @throws org.apache.ki.authz.AuthorizationException
+     * @throws org.apache.shiro.authz.AuthorizationException
      *          if this Subject does not have the role.
      */
     void checkRole(String roleIdentifier) throws AuthorizationException;
 
     /**
      * Asserts this Subject has all of the specified roles by returning quietly if they do or throwing an
      * {@link org.apache.ki.authz.AuthorizationException} if they do not.
      *
      * @param roleIdentifiers the application-specific role identifiers to check (usually role ids or role names).
-     * @throws org.apache.ki.authz.AuthorizationException
+     * @throws org.apache.shiro.authz.AuthorizationException
      *          if this Subject does not have all of the specified roles.
      */
     void checkRoles(Collection<String> roleIdentifiers) throws AuthorizationException;
@@ -305,7 +305,7 @@
      *
      * @param token the token encapsulating the subject's principals and credentials to be passed to the
      *              Authentication subsystem for verification.
      * @throws org.apache.ki.authc.AuthenticationException if the authentication attempt fails.
      * @since 0.9
      */
     void login(AuthenticationToken token) throws AuthenticationException;
@@ -317,7 +317,7 @@
      * <p>Note that even if this Subject's identity has been remembered via 'remember me' services, this method will
      * still return <tt>false</tt> unless the user has actually logged in with proper credentials <em>during their
      * current session</em>.  See the
      * {@link org.apache.ki.authc.RememberMeAuthenticationToken RememberMeAuthenticationToken} class JavaDoc for why
      * this would occur.</p>
      *
      * @return <tt>true</tt> if this Subject has proven their identity during their current session
@@ -16,28 +16,28 @@
  * A <tt>Subject</tt> represents state and security operations for a <em>single</em> application user.
  * These operations include authentication (login/logout), authorization (access control), and
- * session access. It is Ki's primary mechanism for single-user security functionality.
+ * session access. It is Shiro's primary mechanism for single-user security functionality.
  *
  * <p>Note that there are many *Permission methods in this interface overloaded to accept String arguments instead of
@@ -16,28 +16,28 @@
  * a {@link Permission Permission} if desired.  The underlying Authorization subsystem implementations will usually
  * simply convert these String values to {@link Permission Permission} instances and then just call the corresponding
- * type-safe method.  (Ki's default implementations do String-to-Permission conversion for these methods using
- * {@link org.apache.ki.authz.permission.PermissionResolver PermissionResolver}s.)
+ * type-safe method.  (Shiro's default implementations do String-to-Permission conversion for these methods using
+ * {@link org.apache.shiro.authz.permission.PermissionResolver PermissionResolver}s.)
  *
  * <p>These overloaded *Permission methods <em>do</em> forego type-saftey for the benefit of convenience and simplicity,
@@ -55,15 +55,15 @@
      * user, such as a username, or user id, or public key, or anything else you might use in your application to
      * identify a user.  And although given names and family names (first/last) are technically principals as well,
-     * Ki expects the object(s) returned from this method to be uniquely identifying attibute(s) for
+     * Shiro expects the object(s) returned from this method to be uniquely identifying attibute(s) for
      * your application.  This implies that things like given names and family names are usually poor candidates as
      * return values since they are rarely guaranteed to be unique.</p>
@@ -55,15 +55,15 @@
      * <p>Most single-Realm applications would return from this method a single unique principal as noted above
      * (for example a String username or Long user id, etc, etc).  Single-realm applications represent the large
-     * majority of Ki applications.</p>
+     * majority of Shiro applications.</p>
      *
@@ -55,15 +55,15 @@
      *
-     * <p>However, in <em>multi</em>-Realm configurations, which are fully supported by Ki as well, it is
+     * <p>However, in <em>multi</em>-Realm configurations, which are fully supported by Shiro as well, it is
      * possible that the return value encapsulates more than one principal.  Typically multi-realm applications need to
      * retain the unique principals for <em>each</em> Realm so subsequent security checks against these Realms can
@@ -162,7 +162,7 @@
      * Returns <tt>true</tt> if this Subject implies all of the specified permission strings, <tt>false</tt> otherwise.
      *
-     * <p>This is an overloaded method for the corresponding type-safe {@link org.apache.ki.authz.Permission Permission} variant.
+     * <p>This is an overloaded method for the corresponding type-safe {@link org.apache.shiro.authz.Permission Permission} variant.
      * Please see the class-level JavaDoc for more information on these String-based permission methods.
      *
@@ -187,13 +187,13 @@
      *
      * <p>If this subject's existing associated permissions do not {@link Permission#implies(Permission)} imply}
-     * the given permission, an {@link org.apache.ki.authz.AuthorizationException} will be thrown.
+     * the given permission, an {@link org.apache.shiro.authz.AuthorizationException} will be thrown.
      *
      * <p>This is an overloaded method for the corresponding type-safe {@link Permission Permission} variant.
@@ -203,22 +203,22 @@
      *
      * <p>If this subject's exisiting associated permissions do not {@link Permission#implies(Permission) imply}
-     * the given permission, an {@link org.apache.ki.authz.AuthorizationException} will be thrown.
+     * the given permission, an {@link org.apache.shiro.authz.AuthorizationException} will be thrown.
      *
      * @param permission the Permission to check.
@@ -203,22 +203,22 @@
     /**
      * Ensures this Subject
-     * {@link org.apache.ki.authz.Permission#implies(org.apache.ki.authz.Permission) implies} all of the
+     * {@link org.apache.shiro.authz.Permission#implies(org.apache.shiro.authz.Permission) implies} all of the
      * specified permission strings.
      *
@@ -203,22 +203,22 @@
      *
      * If this subject's exisiting associated permissions do not
-     * {@link org.apache.ki.authz.Permission#implies(org.apache.ki.authz.Permission) imply} all of the given permissions,
-     * an {@link org.apache.ki.authz.AuthorizationException} will be thrown.
+     * {@link org.apache.shiro.authz.Permission#implies(org.apache.shiro.authz.Permission) imply} all of the given permissions,
+     * an {@link org.apache.shiro.authz.AuthorizationException} will be thrown.
      *
      * <p>This is an overloaded method for the corresponding type-safe {@link Permission Permission} variant.
@@ -231,12 +231,12 @@
     /**
      * Ensures this Subject
-     * {@link org.apache.ki.authz.Permission#implies(org.apache.ki.authz.Permission) implies} all of the
+     * {@link org.apache.shiro.authz.Permission#implies(org.apache.shiro.authz.Permission) implies} all of the
      * specified permission strings.
      *
@@ -231,12 +231,12 @@
      *
      * If this subject's exisiting associated permissions do not
-     * {@link org.apache.ki.authz.Permission#implies(org.apache.ki.authz.Permission) imply} all of the given permissions,
-     * an {@link org.apache.ki.authz.AuthorizationException} will be thrown.
+     * {@link org.apache.shiro.authz.Permission#implies(org.apache.shiro.authz.Permission) imply} all of the given permissions,
+     * an {@link org.apache.shiro.authz.AuthorizationException} will be thrown.
      *
      * @param permissions the Permissions to check.
@@ -275,20 +275,20 @@
     /**
      * Asserts this Subject has the specified role by returning quietly if they do or throwing an
-     * {@link org.apache.ki.authz.AuthorizationException} if they do not.
+     * {@link org.apache.shiro.authz.AuthorizationException} if they do not.
      *
      * @param roleIdentifier the application-specific role identifier (usually a role id or role name ).
@@ -275,20 +275,20 @@
     /**
      * Asserts this Subject has all of the specified roles by returning quietly if they do or throwing an
-     * {@link org.apache.ki.authz.AuthorizationException} if they do not.
+     * {@link org.apache.shiro.authz.AuthorizationException} if they do not.
      *
      * @param roleIdentifiers the application-specific role identifiers to check (usually role ids or role names).
@@ -305,7 +305,7 @@
      * @param token the token encapsulating the subject's principals and credentials to be passed to the
      *              Authentication subsystem for verification.
-     * @throws org.apache.ki.authc.AuthenticationException if the authentication attempt fails.
+     * @throws org.apache.shiro.authc.AuthenticationException if the authentication attempt fails.
      * @since 0.9
      */
@@ -317,7 +317,7 @@
      * still return <tt>false</tt> unless the user has actually logged in with proper credentials <em>during their
      * current session</em>.  See the
-     * {@link org.apache.ki.authc.RememberMeAuthenticationToken RememberMeAuthenticationToken} class JavaDoc for why
+     * {@link org.apache.shiro.authc.RememberMeAuthenticationToken RememberMeAuthenticationToken} class JavaDoc for why
      * this would occur.</p>
      *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/SubjectException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/SubjectException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/subject/package-info.java Thu Jun 18 03:13:34 2009
@@ -17,11 +17,11 @@
  * under the License.
  */
 /**
  * Components supporting the {@link org.apache.ki.subject.Subject Subject} interface, the most important concept in
  * Ki's API.
  * <p/>
  * A <code>Subject</code> is <em>the</em> primary component when using Ki programatically for single-user
  * security operations, and it is the handle to any accessible user security data.  All single-user
  * authentication, authorization and session operations are performed via a <code>Subject</code> instance.
  */
-package org.apache.ki.subject;
+package org.apache.shiro.subject;
@@ -17,11 +17,11 @@
  */
 /**
- * Components supporting the {@link org.apache.ki.subject.Subject Subject} interface, the most important concept in
- * Ki's API.
+ * Components supporting the {@link org.apache.shiro.subject.Subject Subject} interface, the most important concept in
+ * Shiro's API.
  * <p/>
@@ -17,11 +17,11 @@
  * <p/>
- * A <code>Subject</code> is <em>the</em> primary component when using Ki programatically for single-user
+ * A <code>Subject</code> is <em>the</em> primary component when using Shiro programatically for single-user
  * security operations, and it is the handle to any accessible user security data.  All single-user
  * authentication, authorization and session operations are performed via a <code>Subject</code> instance.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/AntPathMatcher.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/AntPathMatcher.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/AntPathMatcher.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/AntPathMatcher.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
 /**
  * <p>PathMatcher implementation for Ant-style path patterns.
@@ -40,17 +40,17 @@
  * <code>com</code> directory</li>
  * <li><code>com/&#42;&#42;/test.jsp</code> - matches all <code>test.jsp</code>
  * files underneath the <code>com</code> path</li>
  * <li><code>org/apache/ki/&#42;&#42;/*.jsp</code> - matches all <code>.jsp</code>
  * files underneath the <code>org/apache/ki</code> path</li>
  * <li><code>org/&#42;&#42;/servlet/bla.jsp</code> - matches
  * <code>org/apache/ki/servlet/bla.jsp</code> but also
  * <code>org/apache/ki/testing/servlet/bla.jsp</code> and
  * <code>org/servlet/bla.jsp</code></li>
  * </ul>
  *
  * <p><b>N.B.</b>: This class was borrowed (with much appreciation) from the
  * <a href="http://www.springframework.org">Spring Framework</a> with modifications.  We didn't want to reinvent the
  * wheel of great work they've done, but also didn't want to force every Ki user to depend on Spring</p>
  *
  * <p>As per the Apache 2.0 license, the original copyright notice and all author and copyright information have
  * remained in tact.</p>
@@ -40,17 +40,17 @@
  * <li><code>com/&#42;&#42;/test.jsp</code> - matches all <code>test.jsp</code>
  * files underneath the <code>com</code> path</li>
- * <li><code>org/apache/ki/&#42;&#42;/*.jsp</code> - matches all <code>.jsp</code>
- * files underneath the <code>org/apache/ki</code> path</li>
+ * <li><code>org/apache/shiro/&#42;&#42;/*.jsp</code> - matches all <code>.jsp</code>
+ * files underneath the <code>org/apache/shiro</code> path</li>
  * <li><code>org/&#42;&#42;/servlet/bla.jsp</code> - matches
@@ -40,17 +40,17 @@
  * <li><code>org/&#42;&#42;/servlet/bla.jsp</code> - matches
- * <code>org/apache/ki/servlet/bla.jsp</code> but also
- * <code>org/apache/ki/testing/servlet/bla.jsp</code> and
+ * <code>org/apache/shiro/servlet/bla.jsp</code> but also
+ * <code>org/apache/shiro/testing/servlet/bla.jsp</code> and
  * <code>org/servlet/bla.jsp</code></li>
  * </ul>
@@ -40,17 +40,17 @@
  * <p><b>N.B.</b>: This class was borrowed (with much appreciation) from the
  * <a href="http://www.springframework.org">Spring Framework</a> with modifications.  We didn't want to reinvent the
- * wheel of great work they've done, but also didn't want to force every Ki user to depend on Spring</p>
+ * wheel of great work they've done, but also didn't want to force every Shiro user to depend on Spring</p>
  *
  * <p>As per the Apache 2.0 license, the original copyright notice and all author and copyright information have

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/ClassUtils.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/ClassUtils.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/CollectionUtils.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/CollectionUtils.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
 import java.util.ArrayList;
 import java.util.Collection;
@@ -38,7 +38,7 @@
 
     /**
      * Simple method that just returns <code>Collections.EMPTY_SET</code>.
      * This exists to enable type-safe empty collections so other locations in Ki code
      * do not need to worry about suppressing warnings.
      *
      * @param clazz the class of the collection type to return
@@ -38,7 +38,7 @@
     /**
      * Simple method that just returns <code>Collections.EMPTY_SET</code>.
-     * This exists to enable type-safe empty collections so other locations in Ki code
+     * This exists to enable type-safe empty collections so other locations in Shiro code
      * do not need to worry about suppressing warnings.
      *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/Destroyable.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/Destroyable.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/Destroyable.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/Destroyable.java Thu Jun 18 03:13:34 2009
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
 /**
  * Ki container-agnostic interface that indicates that this object requires a callback during destruction.
  *
  * @author Les Hazlewood
  * @author Jeremy Haile
- * @see org.apache.ki.spring.LifecycleBeanPostProcessor
+ * @see org.apache.shiro.spring.LifecycleBeanPostProcessor
  * @since 0.2
  */
 public interface Destroyable {
@@ -16,14 +16,14 @@
 
 /**
- * Ki container-agnostic interface that indicates that this object requires a callback during destruction.
+ * Shiro container-agnostic interface that indicates that this object requires a callback during destruction.
  *
  * @author Les Hazlewood

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/Initializable.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/Initializable.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/Initializable.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/Initializable.java Thu Jun 18 03:13:34 2009
@@ -16,16 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
-import org.apache.ki.KiException;
+import org.apache.shiro.ShiroException;
 
 /**
  * Ki container-agnostic interface that indicates that this object requires initialization.
  *
  * @author Les Hazlewood
  * @author Jeremy Haile
- * @see org.apache.ki.spring.LifecycleBeanPostProcessor
+ * @see org.apache.shiro.spring.LifecycleBeanPostProcessor
  * @since 0.2
  */
 public interface Initializable {
@@ -33,8 +33,8 @@
     /**
      * Initializes this object.
      *
      * @throws org.apache.ki.KiException if an exception occurs during initialization.
      */
-    void init() throws KiException;
+    void init() throws ShiroException;
 
 }
@@ -16,16 +16,16 @@
 
 /**
- * Ki container-agnostic interface that indicates that this object requires initialization.
+ * Shiro container-agnostic interface that indicates that this object requires initialization.
  *
  * @author Les Hazlewood
@@ -33,8 +33,8 @@
      * Initializes this object.
      *
-     * @throws org.apache.ki.KiException if an exception occurs during initialization.
+     * @throws org.apache.shiro.ShiroException if an exception occurs during initialization.
      */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/InstantiationException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/InstantiationException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/JavaEnvironment.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/JavaEnvironment.java Thu Jun 18 03:13:34 2009
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
 /**
  * Internal helper class used to find the Java/JDK version
  * that Ki is operating within, to allow for automatically
  * adapting to the present platform's capabilities.
  *
  * <p>Note that Ki does not support 1.2 or earlier JVMs - only 1.3 and later.
  *
  * <p><em>This class was borrowed and heavily based upon a nearly identical version found in
  * the <a href="http://www.springframework.org/">Spring Framework</a>, with minor modifications.
@@ -16,14 +16,14 @@
 /**
  * Internal helper class used to find the Java/JDK version
- * that Ki is operating within, to allow for automatically
+ * that Shiro is operating within, to allow for automatically
  * adapting to the present platform's capabilities.
  *
@@ -16,14 +16,14 @@
  * adapting to the present platform's capabilities.
  *
- * <p>Note that Ki does not support 1.2 or earlier JVMs - only 1.3 and later.
+ * <p>Note that Shiro does not support 1.2 or earlier JVMs - only 1.3 and later.
  *
  * <p><em>This class was borrowed and heavily based upon a nearly identical version found in

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/JdbcUtils.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/JdbcUtils.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/UnknownClassException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/UnknownClassException.java Thu Jun 18 03:13:34 2009
@@ -16,19 +16,20 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.util;
+package org.apache.shiro.util;
 
-import org.apache.ki.KiException;
+import org.apache.shiro.ShiroException;
 
 
 /**
  * The Ki framework's <code>RuntimeException</code> equivalent of the JDK's
  * <code>ClassNotFoundException</code>, to maintain a RuntimeException paradigm.
  *
  * @author Les Hazlewood
  * @since 0.1
  */
-public class UnknownClassException extends KiException {
+public class UnknownClassException extends ShiroException
+{
 
     /**
      * Creates a new UnknownClassException.
@@ -16,19 +16,20 @@
 
 /**
- * The Ki framework's <code>RuntimeException</code> equivalent of the JDK's
+ * The Shiro framework's <code>RuntimeException</code> equivalent of the JDK's
  * <code>ClassNotFoundException</code>, to maintain a RuntimeException paradigm.
  *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/util/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================